@@ -9,7 +9,7 @@ class Heroku(cl1.CLI):
 	def __init__(self, package=Formats.FilePath(__file__).base()):
 		
 		# variables.
-		self.package = Formats.FilePath(package)
+		self.package = Files.Directory(package)
 		cl1.CLI.__init__(self, 
 			modes={
 				"--push":"Push to heroku.",
